==> ASGIMiddlewareStaticFile-0.1.0.tar.gz: ASGIMiddlewareStaticFile-0.1.0/setup.py <==
#!/usr/bin/env python
# coding=utf-8


# Always prefer setuptools over distutils
from setuptools import setup, find_packages

# To use a consistent encoding
from codecs import open
from os import path

import asgi_middleware_static_file as module

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='ASGIMiddlewareStaticFile',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version=module.__version__,

    description=module.__description__,
    long_description=long_description,

    # The project's main homepage.
    url=module.__project_url__,

    # Author details
    author=module.__author__,
    author_email=module.__author_email__,

    # Choose your license
    license=module.__licence__,

    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 4 - Beta',

        # Indicate who your project is intended for

        # Pick your license as you wish
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',

        'Topic :: Software Development :: Libraries :: Python Modules',
    ],

    # What does your project relate to?
    keywords='asgi middleware staticfile',

    py_modules=['asgi_middleware_static_file'],
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),

    # List run-time dependencies here.  These will be installed by pip when your
    # project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    # install_requires=install_requires,

    python_requires='>=3.5',

    # extras_require={},

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # `pip` to create the appropriate form of executable for the target
    # platform.
    #
    # For example, the following would provide a command called `sample` which
    # executes the function `main` from this package when invoked:
    # entry_points={
    #     'console_scripts': [
    #         '',
    #     ],
    # },
)

==> ASGIMiddlewareStaticFile-0.2.1.tar.gz: ASGIMiddlewareStaticFile-0.2.1/setup.py <==
#!/usr/bin/env python
# coding=utf-8


# Always prefer setuptools over distutils
from setuptools import setup, find_packages

# To use a consistent encoding
from codecs import open
from os import path

import asgi_middleware_static_file as module

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()


# Get install_requires from requirements.txt
def _read_install_requires_from_requirements_txt(base_path, filename):
    _install_requires = []
    with open(path.join(base_path, filename), encoding='utf-8') as req_f:
        lines = req_f.readlines()
        for line in lines:
            if line == '' or line[0] == '#':
                continue

            words = line.rstrip('\n').split(' ')
            if words[0] == '-r':
                _install_requires.extend(_read_install_requires_from_requirements_txt(
                    base_path=base_path, filename=words[1]
                ))

            else:
                _install_requires.append(words[0])

    return _install_requires


install_requires = _read_install_requires_from_requirements_txt(
    base_path=here, filename='requirements.txt'
)

# Setup
setup(
    name='ASGIMiddlewareStaticFile',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version=module.__version__,

    description=module.__description__,
    long_description=long_description,

    # The project's main homepage.
    url=module.__project_url__,

    # Author details
    author=module.__author__,
    author_email=module.__author_email__,

    # Choose your license
    license=module.__licence__,

    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 4 - Beta',

        # Indicate who your project is intended for

        # Pick your license as you wish
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',

        'Topic :: Software Development :: Libraries :: Python Modules',
    ],

    # What does your project relate to?
    keywords='asgi middleware staticfile',

    py_modules=['asgi_middleware_static_file'],
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),

    # List run-time dependencies here.  These will be installed by pip when your
    # project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=install_requires,

    python_requires='>=3.5',

    # extras_require={},

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # `pip` to create the appropriate form of executable for the target
    # platform.
    #
    # For example, the following would provide a command called `sample` which
    # executes the function `main` from this package when invoked:
    # entry_points={
    #     'console_scripts': [
    #         '',
    #     ],
    # },
)
